#!/bin/ksh

####################################################################
# Shell script to create all the 'known' GSICS directories in the
# agreed directory structure.  The script can be run directly in
# a unix or linux OS.
#
# Script usage:
# 
# 1. Put this script into your THREDDS server public directory. 
# 
# e.g. cp makeGSICSdirectories.ksh $THREDDS_HOME/public 
# 
# 2. Run this script: 
# 
#       cd $THREDDS_HOME/public ; makeGSICSdirectories.ksh
#

####################################################################
# Upload directory.
mkdir -p ./upload

####################################################################
# Source Data directories.
####################################################################

####################################################################
# EUMETSAT
mkdir -p ./sourceData/eumetsat/met7-mviri
mkdir -p ./sourceData/eumetsat/metopa-iasi
mkdir -p ./sourceData/eumetsat/msg1-seviri
mkdir -p ./sourceData/eumetsat/msg2-seviri

####################################################################
# JMA
mkdir -p ./sourceData/jma/mtsat1r-jami
mkdir -p ./sourceData/jma/mtsat2-imager

####################################################################
# CMA
mkdir -p ./sourceData/cma

####################################################################
# KMA
mkdir -p ./sourceData/kma

####################################################################
# NOAA
mkdir -p ./sourceData/noaa


####################################################################
# Intermediate Data directories.
####################################################################

####################################################################
# EUMETSAT
mkdir -p ./intermediate/eumetsat/colloc/met7-mviri/metopa-iasi
mkdir -p ./intermediate/eumetsat/colloc/msg1-seviri/metopa-iasi
mkdir -p ./intermediate/eumetsat/colloc/msg2-seviri/metopa-iasi

####################################################################
# JMA
mkdir -p ./intermediate/jma/colloc/mtsat1r-jami/aqua-airs
mkdir -p ./intermediate/jma/colloc/mtsat1r-jami/metopa-iasi
mkdir -p ./intermediate/jma/colloc/mtsat2-imager/aqua-airs
mkdir -p ./intermediate/jma/colloc/mtsat2-imager/metopa-iasi

####################################################################
# CMA
mkdir -p ./intermediate/cma/colloc

####################################################################
# KMA
mkdir -p ./intermediate/cma/colloc

####################################################################
# NOAA
mkdir -p ./intermediate/noaa/colloc

####################################################################
# GSICS Products' directories.
####################################################################

####################################################################
# EUMETSAT Near Real Time Corrections
mkdir -p ./product/eumetsat/nrtc/met7-mviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/nrtc/met7-mviri/metopa-iasi/preop
mkdir -p ./product/eumetsat/nrtc/msg1-seviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/nrtc/msg1-seviri/metopa-iasi/preop
mkdir -p ./product/eumetsat/nrtc/msg2-seviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/nrtc/msg2-seviri/metopa-iasi/preop

####################################################################
# EUMETSAT Re-Aanalysis Corrections
mkdir -p ./product/eumetsat/rac/met7-mviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/rac/met7-mviri/metopa-iasi/preop
mkdir -p ./product/eumetsat/rac/msg1-seviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/rac/msg1-seviri/metopa-iasi/preop
mkdir -p ./product/eumetsat/rac/msg2-seviri/metopa-iasi/demo
mkdir -p ./product/eumetsat/rac/msg2-seviri/metopa-iasi/preop

####################################################################
# JMA Near Real Time Corrections
mkdir -p ./product/jma/nrtc/mtsat1r-jami/aqua-airs/demo
mkdir -p ./product/jma/nrtc/mtsat1r-jami/aqua-airs/preop
mkdir -p ./product/jma/nrtc/mtsat1r-jami/aqua-airs-metopa-iasi/demo
mkdir -p ./product/jma/nrtc/mtsat1r-jami/aqua-airs-metopa-iasi/preop
mkdir -p ./product/jma/nrtc/mtsat1r-jami/metopa-iasi/demo
mkdir -p ./product/jma/nrtc/mtsat1r-jami/metopa-iasi/preop
mkdir -p ./product/jma/nrtc/mtsat2-imager/aqua-airs/demo
mkdir -p ./product/jma/nrtc/mtsat2-imager/aqua-airs/preop
mkdir -p ./product/jma/nrtc/mtsat2-imager/aqua-airs-metopa-iasi/demo
mkdir -p ./product/jma/nrtc/mtsat2-imager/aqua-airs-metopa-iasi/preop
mkdir -p ./product/jma/nrtc/mtsat2-imager/metopa-iasi/demo
mkdir -p ./product/jma/nrtc/mtsat2-imager/metopa-iasi/preop

####################################################################
# JMA Re-Aanalysis Corrections
mkdir -p ./product/jma/rac/mtsat1r-jami/aqua-airs/demo
mkdir -p ./product/jma/rac/mtsat1r-jami/aqua-airs/preop
mkdir -p ./product/jma/rac/mtsat1r-jami/aqua-airs-metopa-iasi/demo
mkdir -p ./product/jma/rac/mtsat1r-jami/aqua-airs-metopa-iasi/preop
mkdir -p ./product/jma/rac/mtsat1r-jami/metopa-iasi/demo
mkdir -p ./product/jma/rac/mtsat1r-jami/metopa-iasi/preop
mkdir -p ./product/jma/rac/mtsat2-imager/aqua-airs/demo
mkdir -p ./product/jma/rac/mtsat2-imager/aqua-airs/preop
mkdir -p ./product/jma/rac/mtsat2-imager/aqua-airs-metopa-iasi/demo
mkdir -p ./product/jma/rac/mtsat2-imager/aqua-airs-metopa-iasi/preop
mkdir -p ./product/jma/rac/mtsat2-imager/metopa-iasi/demo
mkdir -p ./product/jma/rac/mtsat2-imager/metopa-iasi/preop

####################################################################
# CMA Near Real Time Corrections
mkdir -p ./product/cma/nrtc

####################################################################
# CMA Re-Aanalysis Corrections
mkdir -p ./product/cma/rac

####################################################################
# KMA Near Real Time Corrections
mkdir -p ./product/kma/nrtc

####################################################################
# KMA Re-Aanalysis Corrections
mkdir -p ./product/kma/rac

####################################################################
# NOAA Near Real Time Corrections
mkdir -p ./product/noaa/nrtc

####################################################################
# NOAA Re-Aanalysis Corrections
mkdir -p ./product/noaa/rac

exit

